django-awl
**********

Yet another catch-all of tools for django.  Includes utilities for admin,
context processors, CSS colours, view and model mixins, template tags and
unit testing.


Installation
============

.. code-block:: bash

    $ pip install django-awl

Supports
========

django-awl has been tested with Python 2.7, 3.5, 3.6 and Django 1.11 and
2.0.

Docs & Source
=============

Docs: http://django-awl.readthedocs.io/en/latest/

Source: https://github.com/cltrudeau/django-awl
